@@ -21,8 +21,10 @@ Usage::
     select_paginator: SelectPaginator = client.get_paginator("select")
     ```
 """
-from mypy_boto3_sdb.client import SimpleDBClient as Client, SimpleDBClient
+from mypy_boto3_sdb.client import SimpleDBClient
 from mypy_boto3_sdb.paginator import ListDomainsPaginator, SelectPaginator
 
+Client = SimpleDBClient
+
 
 __all__ = ("Client", "ListDomainsPaginator", "SelectPaginator", "SimpleDBClient")
